<?php

namespace Teknisa\FIN\Modules\ContaReceber\Controllers;

use Teknisa\FIN\Controllers\TeknisaCrud;
use Teknisa\Libs\Service\CRUD as CrudService;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\FIN\Modules\ContaReceber\Services\AjusteBoletoService as DtsAjustesBoletoService;

class AjusteBoletoController extends TeknisaCrud{

    protected $dtsAjustesBoletoService;
    protected $dataSourceName = 'ajbolrec_tipoajreceber';
    protected $environment;
    protected $parameterBag;
    protected $crudService;

    public function __construct(
        CrudService $crudService, ParameterBag $parameterBag, Environment $environment, DtsAjustesBoletoService $dtsAjustesBoletoService
    ){
        $this->crudService  = $crudService;
        $this->parameterBag = $parameterBag;
        $this->environment  = $environment;
        $this->dtsAjustesBoletoService = $dtsAjustesBoletoService;
    }

    public function save(DTO\Request $request, DTO\Response $response)
    {
        try {
            $request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
            $rows    = $request->getDataSet()->getRows();

            $nrorg       = $this->environment->getNrOrgTrab();
            $cdfilial    = $rows[0]['CDFILIAL'];
            $nrlanbolrec = $rows[0]['NRLANBOLREC'];
            $idajuctrec  = $rows[0]['IDAJUCTREC'];
            $cdajuctrec  = $rows[0]['CDAJUCTREC'];
            $vrajbolrec  = $rows[0]['VRAJBOLREC'];

            $this->dtsAjustesBoletoService->rotinaInsercaoAjuste(
                $nrorg, $cdfilial, $nrlanbolrec, $idajuctrec, $cdajuctrec, $vrajbolrec
            );

            $response->addMessage(new DTO\Response\Message('Salvo com sucesso'));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function delete(DTO\Request $request, DTO\Response $response)
    {
        try {
            $request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
            $rows    = $request->getDataSet()->getRows();

            $nrorg       = $this->environment->getNrOrgTrab();
            $cdfilial    = $rows[0]['CDFILIAL'];
            $nrlanbolrec = $rows[0]['NRLANBOLREC'];
            $idajuctrec  = $rows[0]['IDAJUCTREC'];
            $cdajuctrec  = $rows[0]['CDAJUCTREC'];
            $vrajbolrec  = $rows[0]['VRAJBOLREC'];

            $this->dtsAjustesBoletoService->rotinaExclusaoAjuste(
                $nrorg, $cdfilial, $nrlanbolrec, $cdajuctrec, $idajuctrec, $vrajbolrec
            );

            $response->addMessage(new DTO\Response\Message('Excluído com sucesso'));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

} 